File Name Translation
=====================

Auto-Translate-File-Names
-------------------------

.. image:: http://img.shields.io/pypi/v/fileNameTranslation.svg
    :target: https://pypi.python.org/pypi/fileNameTranslation
    :alt: Latest Version


.. image:: http://img.shields.io/badge/license-LGPLv3-blue.svg
    :target: https://pypi.python.org/pypi/fileNameTranslation
    :alt: LGPLv3 License


This package will allow you to translate the names of your files


Install
-------

Install with `pip <http://www.pip-installer.org/>`_::

    $ pip install fileNameTranslation

Upgrade
-------

Upgrade with `pip <http://www.pip-installer.org/>`_::

    $ pip install fileNameTranslation --upgrade

Usage
-----

Just run cmd (WinKey + R, then type *cmd* and Enter) then::

    $ fileNameTranslation -h


TODO List:
----------
-

:Author:
    Aviad Levy

:Version: 0.1

:License: `LGPLv3 license <http://www.gnu.org/licenses/lgpl.html>`_
